==> nextcloud-app-mail-0.6.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/hu_HU.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Levelezés",
    "Error while loading the accounts." : "Hiba történt a fiókok betöltése közben.",
    "Fetching Aliases Failed." : "Álnevek betöltése sikertelen.",
    "Saving Aliases Failed." : "Álnevek mentése sikertelen.",
    "Deleting Aliases Failed." : "Álnevek törlése sikertelen.",
    "Error while loading the selected account." : "Hiba történt a kiválasztott fiók betöltése közben.",
    "Loading {folder}" : "Betöltés: {folder}",
    "Searching for {query}" : "Keresés: {query}",
    "Forwarded message" : "Továbbított üzenet",
    "Choose a folder to store the attachment in" : "Válasszon egy mappát a mellékletek tárolásához:",
    "Attachments saved to Files." : "Mellékletek mentve a Fájlokba.",
    "Attachment saved to Files." : "Melléklet mentve a Fájlokba.",
    "Error while saving attachments to Files." : "Hiba történt a mellékletek Fájlokba mentése közben.",
    "Error while saving attachment to Files." : "Hiba történt a melléklet Fájlokba mentése közben.",
    "Message flag could not be set." : "Üzenet zászló nem állítható be.",
    "Invalid account" : "Érvénytelen fiók",
    "Invalid folder" : "Érvénytelen mappa",
    "Unknown error" : "Ismeretlen hiba",
    "Error while creating an account: " : "Hiba történt a fiók létrehozásakor:",
    "Could not load {tag}{name}{endtag}" : "Nem tölthető be: {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Nem tudtuk betölteni: {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Probléma volt a betöltéssel: {tag}{name}{endtag}",
    "We couldn’t load your message" : "Nem tudtuk betölteni az üzenetet",
    "Unable to load the desired message" : "Nem sikerült betölteni a kívánt üzenetet",
    "There was a problem loading the message" : "Probléma volt az üzenet betöltésével",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n új üzenet van ebben a mappában: {folderName}\nFeladó: {from}","%n új üzenet van ebben a mappában: {folderName}\nFeladó: {from}"],
    "Show all folders" : "Minden mappa megjelenítése",
    "Collapse folders" : "Mappák összecsukása",
    "Error while deleting account." : "Hiba történt a fiók törlése közben.",
    "Choose a file to add as attachment" : "Csatolandó fájl kiválasztása",
    "Reply" : "Válasz",
    "Send" : "Küldés",
    "Sending …" : "Küldés...",
    "Message sent!" : "Üzenet elküldve!",
    "Server error" : "Szerver hiba",
    "An unknown error occurred" : "Ismeretlen hiba történt",
    "Opening HTML drafts is not supported yet." : "A HTML vázlatok megnyitása még nem támogatott.",
    "Draft saved!" : "Vázlat mentve.",
    "you" : "te",
    "Send message to {email}" : "Üzenet küldés ide: {email}",
    "No writable calendars found" : "Nem található írható naptár",
    "Error while importing the calendar event" : "Hiba a naptár esemény importálása közben",
    "Error while downloading calendar event" : "Hiba a naptár esemény letöltése közben",
    "Error while deleting message." : "Hiba történt az üzenet törlése közben.",
    "Error while loading messages." : "Hiba történt az üzenetek betöltése közben.",
    "Connecting" : "Csatlakozás",
    "Connect" : "Csatlakozás",
    "Inbox" : "Bejövő",
    "Sent" : "Elküldött",
    "Drafts" : "Vázlatok",
    "Archive" : "Archívum",
    "Trash" : "Lomtár",
    "Junk" : "Szemét",
    "All" : "Mind",
    "Favorites" : "Kedvencek",
    "Creating account failed: " : "Fiók létrehozása sikertelen: ",
    "Auto detect failed. Please use manual mode." : "Automatikus észlelés sikertelen. Használja a manuális módot.",
    "Delete permanently" : "Végleges törlés",
    "& others" : "és mások",
    "All inboxes" : "Minden bejövő",
    "Error loading message" : "Hiba történt az üzenet betöltése közben",
    "Forwarding to %s" : "Továbbítás ide: %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Kattints ide, ha a következő néhány másodpercben lennél automatikusan átirányítva.",
    "Redirect" : "Átirányítás",
    "The link leads to %s" : "A hivatkozás ide mutat: %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarod megnyitni azt az oldalt, akkor térj vissza a <a href=\"%s\">Levelekhez</a>",
    "Continue to %s" : "Folytatás ide: %s",
    "Settings" : "Beállítások",
    "Delete account" : "Fiók törlése",
    "Account Settings" : "Fiók beállítások",
    "Aliases" : "Álnevek",
    "Mail address" : "E-mail cím",
    "Display Name" : "Megjelenített név",
    "Save" : "Mentés",
    "Add attachment from Files" : "Melléklet hozzáadása a Fájlokból",
    "from" : "feladó",
    "to" : "címzett",
    "cc" : "másolat",
    "bcc" : "titkos másolat",
    "Subject" : "Tárgy",
    "Import into calendar" : "Betöltés a naptárba",
    "Download attachment" : "Melléklet letöltése",
    "Save to Files" : "Metés a Fájlokba",
    "Save all to Files" : "Minden mentése a Fájlokba",
    "The images have been blocked to protect your privacy." : "A személyes adataid védelme érdekében a képeket letiltottuk.",
    "Show images from this sender" : "Képek megjelenítése ettől a feladótól",
    "Forward" : "Továbbítás",
    "New message" : "Új üzenet",
    "No search results for" : "Ehhez nincsenek keresési eredmények",
    "Add mail account" : "E-mail fiók hozzáadás",
    "Connect your mail account" : "Kapcsolódás az e-mail fiókodhoz",
    "Name" : "Név",
    "Mail Address" : "E-mail cím",
    "Password" : "Jelszó",
    "Manual configuration" : "Kézi beállítások",
    "IMAP Host" : "IMAP kiszolgáló",
    "IMAP security" : "IMAP biztonság",
    "None" : "Semmi",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP felhasználó",
    "IMAP Password" : "IMAP jelszó",
    "SMTP Host" : "SMTP kiszolgáló",
    "SMTP security" : "SMTP biztonság",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP felhasználó",
    "SMTP Password" : "SMTP jelszó"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.7.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/hu_HU.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Levelezés",
    "Error while loading the accounts." : "Hiba történt a fiókok betöltése közben.",
    "Error while loading the selected account." : "Hiba történt a kiválasztott fiók betöltése közben.",
    "Loading {folder}" : "Betöltés: {folder}",
    "Searching for {query}" : "Keresés: {query}",
    "Forwarded message" : "Továbbított üzenet",
    "Choose a folder to store the attachment in" : "Válasszon egy mappát a mellékletek tárolásához:",
    "Attachments saved to Files." : "Mellékletek mentve a Fájlokba.",
    "Attachment saved to Files." : "Melléklet mentve a Fájlokba.",
    "Error while saving attachments to Files." : "Hiba történt a mellékletek Fájlokba mentése közben.",
    "Error while saving attachment to Files." : "Hiba történt a melléklet Fájlokba mentése közben.",
    "Message flag could not be set." : "Üzenet zászló nem állítható be.",
    "Could not move message." : "Nem lehet áthelyezni az üzenetet",
    "Invalid account" : "Érvénytelen fiók",
    "Invalid folder" : "Érvénytelen mappa",
    "Unknown error" : "Ismeretlen hiba",
    "All inboxes" : "Minden bejövő",
    "Could not load {tag}{name}{endtag}" : "Nem tölthető be: {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Nem tudtuk betölteni: {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Probléma volt a betöltéssel: {tag}{name}{endtag}",
    "We couldn’t load your message" : "Nem tudtuk betölteni az üzenetet",
    "Unable to load the desired message" : "Nem sikerült betölteni a kívánt üzenetet",
    "There was a problem loading the message" : "Probléma volt az üzenet betöltésével",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n új üzenet van ebben a mappában: {folderName}\nFeladó: {from}","%n új üzenet van ebben a mappában: {folderName}\nFeladó: {from}"],
    "Show all folders" : "Minden mappa megjelenítése",
    "Collapse folders" : "Mappák összecsukása",
    "Error while deleting account." : "Hiba történt a fiók törlése közben.",
    "Choose a file to add as attachment" : "Csatolandó fájl kiválasztása",
    "Reply" : "Válasz",
    "Send" : "Küldés",
    "Sending …" : "Küldés...",
    "Message sent!" : "Üzenet elküldve!",
    "Server error" : "Szerver hiba",
    "An unknown error occurred" : "Ismeretlen hiba történt",
    "Opening HTML drafts is not supported yet." : "A HTML vázlatok megnyitása még nem támogatott.",
    "Draft saved!" : "Vázlat mentve.",
    "you" : "te",
    "Send message to {email}" : "Üzenet küldés ide: {email}",
    "No writable calendars found" : "Nem található írható naptár",
    "Error while importing the calendar event" : "Hiba a naptár esemény importálása közben",
    "Error while downloading calendar event" : "Hiba a naptár esemény letöltése közben",
    "Error while deleting message." : "Hiba történt az üzenet törlése közben.",
    "Error while loading messages." : "Hiba történt az üzenetek betöltése közben.",
    "Inbox" : "Bejövő",
    "Sent" : "Elküldött",
    "Drafts" : "Vázlatok",
    "Archive" : "Archívum",
    "Trash" : "Lomtár",
    "Junk" : "Szemét",
    "All" : "Mind",
    "Favorites" : "Kedvencek",
    "Creating account failed: " : "Fiók létrehozása sikertelen: ",
    "Auto detect failed. Please use manual mode." : "Automatikus észlelés sikertelen. Használja a manuális módot.",
    "Delete permanently" : "Végleges törlés",
    "& others" : "és mások",
    "Error loading message" : "Hiba történt az üzenet betöltése közben",
    "Settings" : "Beállítások",
    "Forwarding to %s" : "Továbbítás ide: %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Kattints ide, ha a következő néhány másodpercben lennél automatikusan átirányítva.",
    "Redirect" : "Átirányítás",
    "The link leads to %s" : "A hivatkozás ide mutat: %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarod megnyitni azt az oldalt, akkor térj vissza a <a href=\"%s\">Levelekhez</a>",
    "Continue to %s" : "Folytatás ide: %s",
    "Delete account" : "Fiók törlése",
    "New message" : "Új üzenet",
    "Account Settings" : "Fiók beállítások",
    "Aliases" : "Álnevek",
    "Mail address" : "E-mail cím",
    "Display Name" : "Megjelenített név",
    "Save" : "Mentés",
    "Keyboard shortcuts" : "Gyorsbillentyűk",
    "Newer message" : "Újabb üzenet",
    "Older message" : "Régebbi üzenet",
    "Toggle star" : "Csillagozás váltása",
    "Toggle unread" : "Olvasatlanság váltása",
    "Delete" : "Törlés",
    "Search" : "Keresés",
    "Refresh" : "Frissítés",
    "Connect your mail account" : "Kapcsolódás az e-mail fiókodhoz",
    "Name" : "Név",
    "Mail Address" : "E-mail cím",
    "Password" : "Jelszó",
    "Manual configuration" : "Kézi beállítások",
    "IMAP Host" : "IMAP kiszolgáló",
    "IMAP security" : "IMAP biztonság",
    "None" : "Semmi",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP felhasználó",
    "IMAP Password" : "IMAP jelszó",
    "SMTP Host" : "SMTP kiszolgáló",
    "SMTP security" : "SMTP biztonság",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP felhasználó",
    "SMTP Password" : "SMTP jelszó",
    "Connect" : "Csatlakozás",
    "from" : "feladó",
    "to" : "címzett",
    "cc" : "másolat",
    "bcc" : "titkos másolat",
    "Subject" : "Tárgy",
    "Save all to Files" : "Minden mentése a Fájlokba",
    "Add mail account" : "E-mail fiók hozzáadás",
    "No search results for" : "Ehhez nincsenek keresési eredmények",
    "The images have been blocked to protect your privacy." : "A személyes adataid védelme érdekében a képeket letiltottuk.",
    "Show images from this sender" : "Képek megjelenítése ettől a feladótól",
    "Forward" : "Továbbítás",
    "Import into calendar" : "Betöltés a naptárba",
    "Download attachment" : "Melléklet letöltése",
    "Save to Files" : "Metés a Fájlokba"
},
"nplurals=2; plural=(n != 1);");
